<?php
/**
 * The main template file
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * For example, it puts together the home page when no home.php file exists.
 *
 * @link http://codex.wordpress.org/Template_Hierarchy
 *
 * @package WordPress
 * @subpackage Handart_Theme
 * @since Handart 1.0
 */
$handart_opt = get_option( 'handart_opt' );
get_header();
$handart_bloglayout = 'sidebar';
if(isset($handart_opt['blog_layout']) && $handart_opt['blog_layout']!=''){
	$handart_bloglayout = $handart_opt['blog_layout'];
}
if(isset($_GET['layout']) && $_GET['layout']!=''){
	$handart_bloglayout = $_GET['layout'];
}
$handart_blogsidebar = 'right';
if(isset($handart_opt['sidebarblog_pos']) && $handart_opt['sidebarblog_pos']!=''){
	$handart_blogsidebar = $handart_opt['sidebarblog_pos'];
}
if(isset($_GET['sidebar']) && $_GET['sidebar']!=''){
	$handart_blogsidebar = $_GET['sidebar'];
}
if ( !is_active_sidebar( 'sidebar-1' ) )  {
	$handart_bloglayout = 'nosidebar';
}
$handart_blog_main_extra_class = NULl;
if($handart_blogsidebar=='left') {
	$handart_blog_main_extra_class = 'order-lg-last';
}
$main_column_class = NULL;
switch($handart_bloglayout) {
	case 'sidebar':
		$handart_blogclass = 'blog-sidebar';
		$handart_blogcolclass = 9;
		$main_column_class = 'main-column';
		Handart_Class::handart_post_thumbnail_size('handart-post-thumb');
		break;
	case 'largeimage':
		$handart_blogclass = 'blog-large';
		$handart_blogcolclass = 9;
		$main_column_class = 'main-column';
		Handart_Class::handart_post_thumbnail_size('handart-post-thumbwide');
		break;
	case 'grid':
		$handart_blogclass = 'grid';
		$handart_blogcolclass = 9;
		$main_column_class = 'main-column';
		Handart_Class::handart_post_thumbnail_size('handart-post-thumbwide');
		break;
	default:
		$handart_blogclass = 'blog-nosidebar';
		$handart_blogcolclass = 12;
		$handart_blogsidebar = 'none';
		Handart_Class::handart_post_thumbnail_size('handart-post-thumb');
}
?>
<div class="main-container">
	<div class="breadcrumb-container">
		<div class="container">
			<header class="entry-header">
				<h2 class="entry-title"><?php if(isset($handart_opt) && ($handart_opt !='')) { echo esc_html($handart_opt['blog_header_text']); } else { esc_html_e('Blog', 'handart');}  ?></h2>
			</header>
			<?php Handart_Class::handart_breadcrumb(); ?> 
		</div>
	</div>
	<div class="container">
		<div class="row">
			<div class="col-12 <?php echo 'col-lg-'.$handart_blogcolclass; ?> <?php echo ''.$main_column_class; ?> <?php echo esc_attr($handart_blog_main_extra_class);?>">
				<div class="page-content blog-page blogs <?php echo esc_attr($handart_blogclass); ?>">
					<div class="blog-wrapper">
						<?php if ( have_posts() ) : ?>
							<div class="post-container">
								<?php /* Start the Loop */ ?>
								<?php while ( have_posts() ) : the_post(); ?>
									<?php get_template_part( 'content', get_post_format() ); ?>
								<?php endwhile; ?>
							</div>
							<?php Handart_Class::handart_pagination(); ?>
						<?php else : ?>
							<article id="post-0" class="post no-results not-found">
							<?php if ( current_user_can( 'edit_posts' ) ) :
								// Show a different message to a logged-in user who can add posts.
							?>
								<header class="entry-header">
									<h1 class="entry-title"><?php esc_html_e( 'No posts to display', 'handart' ); ?></h1>
								</header>
								<div class="entry-content">
									<p><?php printf( wp_kses(__( 'Ready to publish your first post? <a href="%s">Get started here</a>.', 'handart' ), array('a'=>array('href'=>array()))), admin_url( 'post-new.php' ) ); ?></p>
								</div><!-- .entry-content -->
							<?php else :
								// Show the default message to everyone else.
							?>
								<header class="entry-header">
									<h1 class="entry-title"><?php esc_html_e( 'Nothing Found', 'handart' ); ?></h1>
								</header>
								<div class="entry-content">
									<p><?php esc_html_e( 'Apologies, but no results were found. Perhaps searching will help find a related post.', 'handart' ); ?></p>
									<?php get_search_form(); ?>
								</div><!-- .entry-content -->
							<?php endif; // end current_user_can() check ?>
							</article><!-- #post-0 -->
						<?php endif; // end have_posts() check ?>
					</div>
				</div>
			</div>
			<?php if($handart_bloglayout!='nosidebar' && is_active_sidebar('sidebar-1')): ?>
				<?php get_sidebar(); ?>
			<?php endif; ?>
		</div>
	</div>
	<!-- brand logo -->
	<?php 
		if(isset($handart_opt['inner_brand']) && function_exists('handart_brands_shortcode') && shortcode_exists( 'ourbrands' ) ){
			if($handart_opt['inner_brand'] && isset($handart_opt['brand_logos'][0]) && $handart_opt['brand_logos'][0]['thumb']!=null) { ?>
				<div class="inner-brands">
					<div class="container">
						<?php if(isset($handart_opt['inner_brand_title']) && $handart_opt['inner_brand_title']!=''){ ?>
							<div class="heading-title style1 ">
								<h3><?php echo esc_html( $handart_opt['inner_brand_title'] ); ?></h3>
							</div>
						<?php } ?>
						<?php echo do_shortcode('[ourbrands]'); ?>
					</div>
				</div>
			<?php }
		}
	?>
	<!-- end brand logo --> 
</div>
<?php get_footer(); ?>